@@ -174,6 +174,9 @@ class SocketIO(object):
 
         def decorator(handler):
             def _handler(sid, *args):
+                if sid not in self.server.environ:
+                    # we don't have record of this client, ignore this event
+                    return '', 400
                 app = self.server.environ[sid]['flask.app']
                 with app.request_context(self.server.environ[sid]):
                     if 'saved_session' in self.server.environ[sid]:
@@ -195,7 +198,7 @@ class SocketIO(object):
                             raise
                         type, value, traceback = sys.exc_info()
                         return err_handler(value)
-                    if flask.session.modified:
+                    if flask.session.modified and sid in self.server.environ:
                         self.server.environ[sid]['saved_session'] = {}
                         self._copy_session(
                             flask.session,
